Source-Changes-HG archive

[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index][Old Index]

[src/trunk]: src/sys/arch/sun3/sun3 use pmap_k* in pagemove().



details:   https://anonhg.NetBSD.org/src/rev/996efb7f2446
branches:  trunk
changeset: 513377:996efb7f2446
user:      chs <chs%NetBSD.org@localhost>
date:      Sun Jul 29 23:51:40 2001 +0000

description:
use pmap_k* in pagemove().

diffstat:

 sys/arch/sun3/sun3/vm_machdep.c |  8 ++++----
 1 files changed, 4 insertions(+), 4 deletions(-)

diffs (22 lines):

diff -r 9a3e5305c9a4 -r 996efb7f2446 sys/arch/sun3/sun3/vm_machdep.c
--- a/sys/arch/sun3/sun3/vm_machdep.c   Sun Jul 29 22:46:36 2001 +0000
+++ b/sys/arch/sun3/sun3/vm_machdep.c   Sun Jul 29 23:51:40 2001 +0000
@@ -1,4 +1,4 @@
-/*     $NetBSD: vm_machdep.c,v 1.61 2001/04/24 04:31:14 thorpej Exp $  */
+/*     $NetBSD: vm_machdep.c,v 1.62 2001/07/29 23:51:40 chs Exp $      */
 
 /*
  * Copyright (c) 1994, 1995 Gordon W. Ross
@@ -340,9 +340,9 @@
                if (pmap_extract(kpmap, tva, NULL) == TRUE)
                        panic("pagemove 3");
 #endif
-               /* pmap_remove does the necessary cache flush.*/
-               pmap_remove(kpmap, fva, fva + NBPG);
-               pmap_enter(kpmap, tva, pa, prot, prot|PMAP_WIRED);
+               /* pmap_kremove does the necessary cache flush.*/
+               pmap_kremove(fva, NBPG);
+               pmap_kenter_pa(tva, pa, prot);
                fva += NBPG;
                tva += NBPG;
                len -= NBPG;



Home | Main Index | Thread Index | Old Index